@@ -11,7 +11,9 @@ patterns = [
     Path('logout', views.logout, name='logout'),
     Path('register', views.register, name='register'),
     Path('reset-password', views.reset_password, name='reset-password'),
-    Path('collections', views.collection, name='collections')
+    Path('collections', views.collections, name='collections'),
+    Path('collections/{collection}/', views.collection, name='collection'),
+    Path('collections/{collection}/{lookup}/', views.collection_obj, name='collection_obj')
     
     
     
