@@ -34,13 +34,29 @@ def static_url(file_path):
     return complete_url    
 
 
-def url(addr):
+def url(addr, *args, **kwargs):
     for route in router.routes:
         if ':' in addr:
             ap, ur = addr.split(':')
             addr = f'{ur}_{ap}'
         if route.name == addr:
-            return f'http://{staticfiles.request.http_host}'+ route.path 
+            sp_u = route.path.split('/')
+            for i,p in enumerate(sp_u):
+                
+                if "{" and "}" in p:
+                    v = p[1:-1]
+                    param = kwargs.get(v)
+                    if not param:
+
+                        raise Exception(f'''
+    {v} can"t be None.
+    it suppose to be url('{addr.replace('_', ':')}', {v}=*something* ...)
+
+                            ''')
+                    sp_u[i] = param
+                    
+            return f'http://{staticfiles.request.http_host}' + '/'.join(sp_u)
+   
     return None
 
 
