@@ -48,32 +48,32 @@ class Render(Response):
         super().__init__(request, status_code, content_type)
         # env = Environment(loader=PackageLoader('jinja2', '/'))
 
-        if self.is_available(content) is not None:
+        # if self.is_available(content) is not None:
             # template = env.get_template(self.is_available(content))
-            file_loader = FileSystemLoader(self.templates_folders)
-            env = Environment(loader=file_loader)
-            env.trim_blocks = True
-            env.lstrip_blocks = True
-            env.rstrip_blocks = True
-            globals_obj = request.context.get_objs()
-            for k, v in globals_obj.items():
-                env.globals[k] = v
-            template = env.get_template(self.is_available(content))
-            # print(**request.context.get_objs())
-            content = template.render(
-                **{'csrf': request.csrf,'user': request.user, 'messages': messages_broker.get_messages(request), **request.params, **context})
-        else:
-            content = f'Template {content} not found.'
+        file_loader = FileSystemLoader(self.templates_folders)
+        env = Environment(loader=file_loader)
+        env.trim_blocks = True
+        env.lstrip_blocks = True
+        env.rstrip_blocks = True
+        globals_obj = request.context.get_objs()
+        for k, v in globals_obj.items():
+            env.globals[k] = v
+        template = env.get_template(content)
+        # print(**request.context.get_objs())
+        content = template.render(
+            **{'csrf': request.csrf,'user': request.user, 'messages': messages_broker.get_messages(request), **request.params, **context})
+        # else:
+        #     content = f'Template {content} not found.'
         # content = template.render(*context)
         self.response_content.append(content.encode())
 
-    def is_available(self, filename):
-        for path in self.templates_folders:
-            if not path.endswith('/'):
-                path = path + '/'
-            if os.path.isfile(path + filename):
-                return filename
-        return None
+    # def is_available(self, filename):
+    #     for path in self.templates_folders:
+    #         if not path.endswith('/'):
+    #             path = path + '/'
+    #         if os.path.isfile(path + filename):
+    #             return filename
+        # return None
 
 
 class HttpResponse(Response):
